<?php
/**
 * @file class_erErrorReport.inc
 * A container class for an error report
 * @author Roland Hieber (roland.hieber@wilhelm-gym.net)
 * @date 18.10.2007
 * 
 * Copyright © 2007 Roland Hieber
 * 
 * Permission is hereby granted, free of charge, to any person obtaining
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *  
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

/** This class represents a dataset stored in the SQL table */
class erErrorReport {

  /**
   * @privatesection
   * (int) Unique ID in the database
   */
  var $nUid;
  /** (timestamp) Date when the report was created */
  var $tsDate;
  /** (string) Account name of the owner */
  var $strOwner;
  /** (string) Machine to which the report refers */
  var $strMachine;
  /** (string) Text of the report */
  var $strText;
  /** (string) Comments of an administrator */
  var $strComment;
  /** (string) Account name of the one who wrote the comment */
  var $strCommentOwner;
  /** (bool) Indicate if the report can be seen by non-administrators */
  var $bHidden;
  
  /**
   * @publicsection
   * @name Constructor
   * @{
   */
  /**
   * Constructor. Used to set the data.
   * @param $tsDate (timestamp) Date when the report was created
   * @param $strOwner (string) Account name of the creator
   * @param $strMachine (string) Machine to which the report refers
   * @param $strText (string) Text of the report
   * @param $bHidden (bool) Indicate if the report can be seen by
   *  non-administrators
   * @return erError
   */
  function erErrorReport($tsDate = null, $strOwner = null, $strMachine = null, $strText = null,
    $bHidden = false) {
    $this->nUid = null;
    $this->tsDate = intval($tsDate);
    $this->strOwner = $strOwner;
    $this->strMachine = $strMachine;
    $this->strText = $strText;
    $this->strComment = null;
    $this->strCommentOwner = null;
    $this->bHidden = ($bHidden == true);
  }
  
  ////////////////////////////// SETTER FUNCTIONS //////////////////////////////
  
  /**
   * @}
   * @name Setter functions
   * @{
   */
  
  /**
   * Set the unique ID
   * @param $value (int)
   */
  function setUid($value) { $this->nUid = $value; }
  /**
   * Set the date
   * @param $value (timestamp)
   */
  function setDate($value) { $this->tsDate = intval($value); }
  /**
   * Set the account name of the owner
   * @param $value (string)
   */
  function setOwner($value) { $this->strOwner = $value; }
  /**
   * Set the label of the machine to which the report refers
   * @param $value (string)
   */
  function setMachine($value) { $this->strMachine = $value; }
  /**
   * Set the text of the report
   * @param $value (string)
   */
  function setText($value) { $this->strText = $value; }

  /**
   * Set the comment of an adminstrator
   * @param $strComment (string) Comment
   * @param $strAct (string) Account name of the person who sets the comment
   */
  function setComment($strComment, $strAct) {
    $this->strComment = $strComment;
    $this->strCommentOwner = $strAct;
  }
  /**
   * Set the visibility of the report
   * @param $value (bool) <tt>true</tt>: the report is only visible for
   *  administrators
   */
  function setVisibility($value) { $this->bHidden = $value; }
  
  ////////////////////////////// GETTER FUNCTIONS //////////////////////////////
  
  /**
   * @}
   * @name Getter functions
   * @{
   */
  
  /**
   * Get the unique ID in the database
   * @return (int)
   */
  function getUid() { return intval($this->nUid); }
  /**
   * Get the date when the report was created
   * @return (timestamp)
   */
  function getDate() { return intval($this->tsDate); }
  /**
   * Get the account name of the creator 
   * @return (string)
   */
  function getOwner() { return $this->strOwner; }
  /**
   * Get the label of the machine to which the report refers
   * @return (string)
   */
  function getMachine() { return $this->strMachine; }
  /**
   * Get the tet of the report
   * @return (string)
   */
  function getText() { return $this->strText; }
  /**
   * Get the comment from an administrator
   * @return (string)
   */
  function getComment() { return $this->strComment; }
  /**
   * Get the account name of the one who wrote the comment
   * @return (string)
   */
  function getCommentOwner() { return $this->strCommentOwner; }
  /**
   * Determine if the report can be seen by non-administrators
   * @return (bool)
   */
  function isHidden() { return ($this->bHidden == true); }
  
  /**@}*/
}
?>
